@@ -4,10 +4,11 @@ return array(
         '%.*%' => array(
             'test_url' => 'http://www.franceculture.fr/emission-culture-eco-la-finance-aime-toujours-la-france-2016-01-08',
             'body' => array(
-                '//div[@class="listen"]',
-                '//div[@class="field-items"]',
+                '//div[@class="heading"]/*/*/div[contains(@class,"player-inline")]',
+                '//article/div[@class="text-zone"]',
             ),
             'strip' => array(
+                '//ul[@class="tags"]',
             ),
         )
     )
